# AlphaDom (v0.1.4)

Playing Dominion with Deep Reinforcement Learning.

## References

1. [AlphaZero](https://arxiv.org/abs/1712.01815)
   - Notes
   - Thoughts
2. [AlphaStar](https://arxiv.org/abs/1902.01724)
   - Notes
   - Thoughts
3. [Deep RL for Imperfect Information Games](https://arxiv.org/pdf/2007.13544)
   - Notes
   - Thoughts
